==========================================
Class definitions used for parsing results
==========================================

.. automodule:: abed.results.models
    :members:
    :undoc-members:
    :show-inheritance:
